@@ -137,38 +137,3 @@ class TestOvercloudUpdateRun(fakes.TestOvercloudUpdateRun):
         ]
         self.assertRaises(ParserException, lambda: self.check_parser(
             self.cmd, argslist, verifylist))
-
-
-class TestOvercloudUpdateConverge(fakes.TestOvercloudUpdateConverge):
-
-    def setUp(self):
-        super(TestOvercloudUpdateConverge, self).setUp()
-
-        # Get the command object to test
-        app_args = mock.Mock()
-        app_args.verbose_level = 1
-        self.cmd = overcloud_update.UpdateConverge(self.app, app_args)
-
-    @mock.patch('tripleoclient.utils.ensure_run_as_normal_user')
-    @mock.patch('tripleoclient.utils.prompt_user_for_confirmation',
-                return_value=True)
-    @mock.patch(
-        'tripleoclient.v1.overcloud_deploy.DeployOvercloud.take_action')
-    def test_update_converge(self, deploy_action, mock_confirm,
-                             mock_usercheck):
-        argslist = ['--templates', '--stack', 'cloud']
-        verifylist = [
-            ('stack', 'cloud')
-        ]
-        parsed_args = self.check_parser(self.cmd, argslist, verifylist)
-
-        with mock.patch('os.path.exists') as mock_exists, \
-                mock.patch('os.path.isfile') as mock_isfile:
-            mock_exists.return_value = True
-            mock_isfile.return_value = True
-            self.cmd.take_action(parsed_args)
-            mock_usercheck.assert_called_once()
-            assert('/usr/share/openstack-tripleo-heat-templates/'
-                   'environments/lifecycle/update-converge.yaml'
-                   in parsed_args.environment_files)
-            deploy_action.assert_called_once_with(parsed_args)
