@@ -111,6 +111,18 @@ class Build(command.Command):
                 "host distro. (default: %(default)s)"
             ),
         )
+        parser.add_argument(
+            "--tcib-extras",
+            dest="tcib_extras",
+            default=None,
+            metavar="<key=val>",
+            action='append',
+            help=_(
+                "TCIB extra variables you want to pass. They can be later "
+                "used within TCIB files as conditonals. Can be passed "
+                "multiple times(default: %(default)s)"
+            ),
+        )
         parser.add_argument(
             "--exclude",
             dest="excludes",
@@ -198,7 +210,6 @@ class Build(command.Command):
             dest="volumes",
             metavar="<volume-path>",
             default=[
-                "/etc/yum.repos.d:/etc/distro.repos.d:z",
                 "/etc/pki/rpm-gpg:/etc/pki/rpm-gpg:z",
             ],
             action="append",
@@ -208,6 +219,16 @@ class Build(command.Command):
                 "(default: %(default)s)"
             ),
         )
+        parser.add_argument(
+            "--repo-dir",
+            dest="repo_dir",
+            metavar="<repo-dir>",
+            default="/etc/yum.repos.d",
+            help=_(
+                "Define a custom directory containing the repo files. This is "
+                "useful when building containers from a different OS release."
+            ),
+        )
         parser.add_argument(
             "--work-dir",
             dest="work_dir",
@@ -564,6 +585,15 @@ class Build(command.Command):
                     "ansible_connection": "local",
                 }
             )
+            if parsed_args.tcib_extras:
+                for extras in parsed_args.tcib_extras:
+                    key, value = extras.split('=')
+                    # Enforce format in order to get some consistency
+                    if not key.startswith('tcib_'):
+                        raise ValueError('Wrong key format {key}. '
+                                         'We expect "tcib_" prefix, such as '
+                                         'tcib_{key}'.format(key=key))
+                    image_config[key] = value
 
             if parsed_args.rhel_modules:
                 rhel_modules = {}
@@ -669,6 +699,10 @@ class Build(command.Command):
         # Ensure anything not intended to be built is excluded
         excludes.extend(self.rectify_excludes(images_to_prepare))
         self.log.info("Images being excluded: {}".format(excludes))
+        volumes = parsed_args.volumes
+        volumes.append(
+            f"{parsed_args.repo_dir}:/etc/distro.repos.d:z"
+        )
 
         if not parsed_args.skip_build:
             bb = buildah.BuildahBuilder(
@@ -680,7 +714,7 @@ class Build(command.Command):
                 namespace=parsed_args.namespace,
                 registry_address=parsed_args.registry,
                 push_containers=parsed_args.push,
-                volumes=parsed_args.volumes,
+                volumes=volumes,
                 excludes=list(set(excludes)),
                 build_timeout=parsed_args.build_timeout,
                 debug=self.app.options.debug
